@@ -242,8 +242,9 @@ def zeroImgVolumes(sdUUID, imgUUID, volUUIDs, discard):
         try:
             log.debug('Removing volume %s task %s', volUUID, taskid)
             deleteVolumes(sdUUID, volUUID)
-        except se.CannotRemoveLogicalVolume:
-            log.exception("Removing volume %s task %s failed", volUUID, taskid)
+        except se.CannotRemoveLogicalVolume as e:
+            log.exception("Removing volume %s task %s failed: %s",
+                          volUUID, taskid, e)
 
         log.debug('Zero volume thread finished for '
                   'volume %s task %s', volUUID, taskid)
@@ -702,7 +703,7 @@ class BlockStorageDomainManifest(sd.StorageDomainManifest):
                 self.log.warning("Can't unlink %s. %s", lPath, e)
             else:
                 removedPaths.append(lPath)
-        self.log.debug("removed: %s", removedPaths)
+        self.log.info("removed: %s", removedPaths)
         return tuple(removedPaths)
 
     def rmDCImgDir(self, imgUUID, volsImgs):
@@ -798,7 +799,7 @@ class BlockStorageDomainManifest(sd.StorageDomainManifest):
             dst = os.path.join(domMD, lvName)
             if not os.path.lexists(dst):
                 src = lvm.lvPath(self.sdUUID, lvName)
-                self.log.debug("Creating symlink from %s to %s", src, dst)
+                self.log.info("Creating symlink from %s to %s", src, dst)
                 os.symlink(src, dst)
 
     def refresh(self):
@@ -1302,7 +1303,7 @@ class BlockStorageDomain(sd.StorageDomain):
 
     def linkBCImage(self, imgPath, imgUUID):
         dst = self.getLinkBCImagePath(imgUUID)
-        self.log.debug("Creating symlink from %s to %s", imgPath, dst)
+        self.log.info("Creating symlink from %s to %s", imgPath, dst)
         try:
             os.symlink(imgPath, dst)
         except OSError as e:
@@ -1316,7 +1317,7 @@ class BlockStorageDomain(sd.StorageDomain):
     def unlinkBCImage(self, imgUUID):
         img_path = self.getLinkBCImagePath(imgUUID)
         if os.path.islink(img_path):
-            self.log.debug("Removing image directory link %r", img_path)
+            self.log.info("Removing image directory link %r", img_path)
             os.unlink(img_path)
 
     def createImageLinks(self, srcImgPath, imgUUID, volUUIDs):
@@ -1337,7 +1338,7 @@ class BlockStorageDomain(sd.StorageDomain):
         for volUUID in volUUIDs:
             srcVol = os.path.join(srcImgPath, volUUID)
             dstVol = os.path.join(imgRunDir, volUUID)
-            self.log.debug("Creating symlink from %s to %s", srcVol, dstVol)
+            self.log.info("Creating symlink from %s to %s", srcVol, dstVol)
             try:
                 os.symlink(srcVol, dstVol)
             except OSError as e:
