@@ -37,11 +37,13 @@ from vdsm.network import api as net_api
 from vdsm.virt import libvirtnetwork
 from vdsm.virt import vmxml
 
+from . import compat
 from . import core
 from . import hwclass
 
 VHOST_SOCK_DIR = os.path.join(constants.P_VDSM_RUN, 'vhostuser')
 
+METADATA_KEYS = ('network',)
 
 METADATA_NESTED_KEYS = ('custom', 'portMirroring')
 
@@ -68,8 +70,7 @@ class Interface(core.Base):
         # dev_class unused
         attrs = {'mac_address': self.macAddr}
         data = core.get_metadata_values(self)
-        if hasattr(self, 'network'):
-            data['network'] = self.network
+        core.get_simple_metadata(data, self, METADATA_KEYS)
         core.get_nested_metadata(data, self, METADATA_NESTED_KEYS)
         return attrs, data
 
@@ -463,7 +464,7 @@ class Interface(core.Base):
                 vm.conf['devices'].append(nicDev)
 
     def config(self):
-        return None
+        return compat.interface_config(super(Interface, self).config())
 
     def __repr__(self):
         s = ('<Interface name={name}, type={self.device}, mac={self.macAddr} '
